@@ -8,11 +8,14 @@ client = RealtimeX('YOUR_API_KEY', {
     'encrypted': False
 })
 
-# Connection events
+# Bind connection events BEFORE connecting
 client.connection.bind('connecting', lambda: print('🔄 Connecting...'))
 client.connection.bind('connected', lambda: print('✅ Connected!'))
 client.connection.bind('disconnected', lambda: print('❌ Disconnected'))
 
+# Now connect
+client.connect()
+
 # Subscribe to channel
 channel = client.subscribe('test-channel')
 
