@@ -10,6 +10,14 @@ class TestRealtimeX(unittest.TestCase):
         
         self.assertEqual(client.api_key, 'test-api-key')
         self.assertEqual(client.options['cluster'], 'eu')
+        # No auto-connect anymore
+        mock_connection.return_value.connect.assert_not_called()
+
+    @patch('src.realtimex.Connection')
+    def test_explicit_connect(self, mock_connection):
+        client = RealtimeX('test-api-key')
+        client.connect()
+        
         mock_connection.return_value.connect.assert_called_once()
 
     @patch('src.realtimex.Connection')
